"use strict";
var util = require('./util');
var OBD = require('obd-parser');
var Promise = require('bluebird');
var table = require('table');
var connection_1 = require('./connection');
function default_1(pids) {
    Promise.mapSeries(pids, function (pidCodeOrName) {
        return util.getPidByCode(pidCodeOrName) || util.getPidByName(pidCodeOrName);
    })
        .then(function (pids) { return poll(pids); });
}
exports.__esModule = true;
exports["default"] = default_1;
function poll(pids) {
    return connection_1.ensureObdIsConnected()
        .then(function () {
        return Promise.mapSeries(pids, function (p) {
            var poller = new OBD.ECUPoller({
                pid: p,
                interval: null
            });
            var pd = poller.poll();
            return pd;
        });
    })
        .then(function (pollReults) {
        console.log('\nResults:\n');
        var data = [];
        pollReults.forEach(function (p) {
            // This will always be a string for us so we can cast it
            data.push([p.name, p.value && p.value.toFixed ? p.value.toFixed(2) : p.value]);
        });
        console.log(table.table(data, {
            border: table.getBorderCharacters('norc')
        }));
        // TODO: kill connections and close process clean
        process.exit(0);
    })
        .catch(function (e) {
        console.error('Error occurred when polling:');
        console.error(e.stack);
    });
}
