"use strict";
var __extends = (this && this.__extends) || function (d, b) {
    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
    function __() { this.constructor = d; }
    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
};
var OBD = require('obd-parser');
var events_1 = require('events');
var g = global;
var program = g.program;
var connection;
var Connection = (function (_super) {
    __extends(Connection, _super);
    function Connection() {
        _super.call(this);
        this.connected = false;
    }
    Connection.prototype.isConnected = function () {
        return this.connected;
    };
    Connection.prototype.connect = function (connector) {
        var self = this;
        if (this.connected) {
            self.emit('connected');
        }
        else {
            console.log("\nConnecting via \"" + program.connection + "\" type...");
            // Need to initialise the OBD module with a "connector" before starting
            OBD.init(connector)
                .then(function () {
                console.log('OBD module intialised...');
                self.connected = true;
                self.emit('connected');
            })
                .catch(function (e) {
                console.log('failed to connect to obd', e.stack);
                process.exit(1);
            });
        }
    };
    return Connection;
}(events_1.EventEmitter));
function getConnector() {
    if (program.connection === 'fake') {
        return require('obd-parser-development-connection')();
    }
    else if (program.connection === 'serial') {
        return require('obd-parser-serial-connection')({
            serialPath: program.interface,
            serialOpts: {
                baudrate: program.baudrate ? parseInt(program.baudrate) : 38400
            }
        });
    }
    else {
        throw new Error("please specify a valid connection type using option -c");
    }
}
function ensureObdIsConnected() {
    // Use a serial connection to connect
    var connector = getConnector();
    if (connection && connection.isConnected()) {
        return Promise.resolve();
    }
    else {
        if (!connection) {
            // Connection needs to be initialised if this is the first call
            connection = new Connection();
            connection.connect(connector);
        }
        return new Promise(function (resolve, reject) {
            connection.once('connected', resolve);
            connection.once('error', reject);
        });
    }
}
exports.ensureObdIsConnected = ensureObdIsConnected;
